################################################################################
##                                                                            ##
##  This file is part of NCrystal (see https://mctools.github.io/ncrystal/)   ##
##                                                                            ##
##  Copyright 2015-2021 NCrystal developers                                   ##
##                                                                            ##
##  Licensed under the Apache License, Version 2.0 (the "License");           ##
##  you may not use this file except in compliance with the License.          ##
##  You may obtain a copy of the License at                                   ##
##                                                                            ##
##      http://www.apache.org/licenses/LICENSE-2.0                            ##
##                                                                            ##
##  Unless required by applicable law or agreed to in writing, software       ##
##  distributed under the License is distributed on an "AS IS" BASIS,         ##
##  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  ##
##  See the License for the specific language governing permissions and       ##
##  limitations under the License.                                            ##
##                                                                            ##
################################################################################

##################################################################################
#                                                                                #
# Exports NCrystal targets, and provides a few PATHS and values of a few build   #
# options.                                        #                              #
#                                                                                #
# Geant4 targets will not be exported from this file. If Geant4 targets are      #
# needed, one should use find_package(G4NCrystal) instead of                     #
# find_package(NCrystal) (the former will also provide targets and variables     #
# from the latter).                                                              #
#                                                                                #
##################################################################################


#Export a few directory paths (relocatable):
set( NCrystal_CMAKEDIR "${CMAKE_CURRENT_LIST_DIR}" )
get_filename_component( NCrystal_DIR "${NCrystal_CMAKEDIR}/../../../" ABSOLUTE )
get_filename_component( NCrystal_DATAROOT "${NCrystal_DIR}/share/NCrystal" ABSOLUTE )

get_filename_component( NCrystal_BINDIR "${NCrystal_CMAKEDIR}/../../../bin" ABSOLUTE )
get_filename_component( NCrystal_LIBDIR "${NCrystal_CMAKEDIR}/../" ABSOLUTE )
get_filename_component( NCrystal_INCDIR "${NCrystal_CMAKEDIR}/../../../include" ABSOLUTE )
get_filename_component( NCrystal_PYPATH "${NCrystal_CMAKEDIR}/../../../share/NCrystal/python" ABSOLUTE )#FIXME: Only if appropriate
get_filename_component( NCrystal_DATAFILESDIR "${NCrystal_CMAKEDIR}/../../../share/NCrystal/data" ABSOLUTE )#FIXME: Only if appropriate

#The NCrystal targets (not including the G4NCrystal targets!):
if(NOT TARGET NCrystal::NCrystal)
  include( "${NCrystal_CMAKEDIR}/NCrystalTargets.cmake" )
endif()

#Config variables:
set( NCrystal_OPTION_BUILD_EXAMPLES  ON )
set( NCrystal_OPTION_BUILD_G4HOOKS   OFF )
set( NCrystal_OPTION_BUILD_EXTRA     OFF )
set( NCrystal_OPTION_INSTALL_MCSTAS  ON )
set( NCrystal_OPTION_INSTALL_PY      ON )
set( NCrystal_OPTION_INSTALL_DATA    ON )
set( NCrystal_OPTION_EMBED_DATA      OFF )
set( NCrystal_OPTION_INSTALL_SETUPSH ON )
set( NCrystal_OPTION_MODIFY_RPATH    ON )

#Libname:
set( NCrystal_LIBNAME  )

#Various scripts:
set( NCrystal_CMD_NCMAT2CPP ${NCrystal_BINDIR}/ncrystal_ncmat2cpp )
if ( NOT EXISTS NCrystal_NCMAT2CPP )
  set( NCrystal_NCMAT2CPP "")
endif()
set( NCrystal_CMD_NCRYSTALCONFIG ${NCrystal_BINDIR}/ncrystal-config )
if ( NOT EXISTS NCrystal_CMD_NCRYSTALCONFIG )
  set( NCrystal_CMD_NCRYSTALCONFIG "")
endif()
set( NCrystal_CMD_NCRYSTALINSPECTFILE ${NCrystal_BINDIR}/ncrystal_inspectfile )
if ( NOT EXISTS NCrystal_CMD_NCRYSTALINSPECTFILE )
  set( NCrystal_CMD_NCRYSTALINSPECTFILE "")
endif()
